"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.api = void 0;
const client_1 = require("@deep-foundation/hasura/client");
const api_1 = require("@deep-foundation/hasura/api");
const client_2 = require("../imports/client");
const chai_1 = require("chai");
const handlers_1 = require("../imports/handlers");
const promise_1 = require("../imports/promise");
jest.setTimeout(120000);
exports.api = new api_1.HasuraApi({
    path: process.env.DEEPLINKS_HASURA_PATH,
    ssl: !!+process.env.DEEPLINKS_HASURA_SSL,
    secret: process.env.DEEPLINKS_HASURA_SECRET,
});
const apolloClient = (0, client_1.generateApolloClient)({
    path: `${process.env.DEEPLINKS_HASURA_PATH}/v1/graphql`,
    ssl: !!+process.env.DEEPLINKS_HASURA_SSL,
    secret: process.env.DEEPLINKS_HASURA_SECRET,
});
const deep = new client_2.DeepClient({ apolloClient });
describe('tree', () => {
    it(`promiseTree`, () => __awaiter(void 0, void 0, void 0, function* () {
        let linksToDelete = [];
        const typeTypeLinkId = yield deep.id("@deep-foundation/core", "Type");
        const handleInsertTypeLinkId = yield deep.id("@deep-foundation/core", "HandleInsert");
        const { data: [{ id: customTypeLinkId }] } = yield deep.insert({
            type_id: typeTypeLinkId,
        });
        linksToDelete.push(customTypeLinkId);
        const handler = yield (0, handlers_1.insertHandler)(handleInsertTypeLinkId, customTypeLinkId, `async () => {}`);
        const { data: [{ id: customLinkId }] } = yield deep.insert({
            type_id: customTypeLinkId
        });
        linksToDelete.push(customLinkId);
        yield (0, promise_1.delay)(5000);
        try {
            const { data: promiseTreeLinksDownToCustomLink } = yield deep.select({
                up: {
                    parent_id: { _eq: customLinkId },
                    tree_id: { _eq: yield deep.id("@deep-foundation/core", "promiseTree") }
                }
            });
            console.log({ promiseTreeLinksDownToCustomLink });
            linksToDelete = [...linksToDelete, ...promiseTreeLinksDownToCustomLink.map(link => link.id)];
            const thenTypeLinkId = yield deep.id("@deep-foundation/core", "Then");
            const thenLinkId = promiseTreeLinksDownToCustomLink.find(link => link.type_id === thenTypeLinkId);
            chai_1.assert.notEqual(thenLinkId, undefined);
            const promiseTypeLinkId = yield deep.id("@deep-foundation/core", "Promise");
            const promiseLinkId = promiseTreeLinksDownToCustomLink.find(link => link.type_id === promiseTypeLinkId);
            chai_1.assert.notEqual(promiseLinkId, undefined);
            const resolvedTypeLinkId = yield deep.id("@deep-foundation/core", "Resolved");
            const resolvedLinkId = promiseTreeLinksDownToCustomLink.find(link => link.type_id === resolvedTypeLinkId);
            chai_1.assert.notEqual(resolvedLinkId, undefined);
        }
        finally {
            yield (0, handlers_1.deleteHandler)(handler);
            yield deep.delete(linksToDelete);
        }
    }));
});
//# sourceMappingURL=tree.js.map